InstrumentedChannelMetric

Trait InstrumentedChannelMetric 

pub trait InstrumentedChannelMetric {
    // Required method
    fn bump(&self);
}
Available on crate feature async only.
A trait describing a metric that can be used with an instrumented_unbounded_channel.

Required Methods

fn bump(&self)

Bump the metric, increasing the count of operators (send or receives) that occurred.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors