consolidate_update_iter

Function consolidate_update_iter 

pub fn consolidate_update_iter<D: PartialEq, T: PartialEq, R: Semigroup>(
    iter: impl Iterator<Item = (D, T, R)>,
) -> impl Iterator<Item = (D, T, R)>
Available on crate feature differential-dataflow only.
Proactively consolidate adjacent elements in an iterator. (Triple / update edition.)

If the input iterator is sorted by D and T, the outputs will be both sorted and fully consolidated. If the input is not sorted, the output will probably not be either… but still equivalent from a differential perspective and slightly smaller.