merge_iters_by

Function merge_iters_by 

pub fn merge_iters_by<I: Iterator, F: Fn(&I::Item, &I::Item) -> Ordering>(
    iters: impl IntoIterator<Item = I>,
    merge_by: F,
) -> impl Iterator<Item = I::Item>
Combine a stream of iterators into a new iterator, according to the provided merge function.

If the input iterators are sorted by the provided function, the resulting iterators will be sorted by that function also.