soft_assert_none_no_log

Macro soft_assert_none_no_log 

macro_rules! soft_assert_none_no_log {
    ($val:expr $(, $($msg:tt)+)?) => { ... };
}
Available on crate feature assert-no-tracing only.
Asserts that the provided expression, that returns an Option, is None if soft assertions are enabled.

Unlike soft_assert_eq_no_log!(x, None), a failure reports the value held by the Some(_) variant. See assert_none.

Soft assertions have a small runtime cost even when disabled. See ore::assert for details.