pub trait Zeroize {
// Required method
fn zeroize(&mut self);
}Expand description
Trait for securely erasing values from memory.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl Zeroize for PrivateKeyDer<'static>
Available on crate feature alloc only.
impl Zeroize for PrivateKeyDer<'static>
alloc only.Sourceimpl Zeroize for PrivatePkcs1KeyDer<'static>
Available on crate feature alloc only.
impl Zeroize for PrivatePkcs1KeyDer<'static>
alloc only.Sourceimpl Zeroize for PrivatePkcs8KeyDer<'static>
Available on crate feature alloc only.
impl Zeroize for PrivatePkcs8KeyDer<'static>
alloc only.Sourceimpl Zeroize for PrivateSec1KeyDer<'static>
Available on crate feature alloc only.
impl Zeroize for PrivateSec1KeyDer<'static>
alloc only.Sourceimpl<A, B, C, D, E, F, G, H, I, J> Zeroize for (A, B, C, D, E, F, G, H, I, J)
impl<A, B, C, D, E, F, G, H, I, J> Zeroize for (A, B, C, D, E, F, G, H, I, J)
Sourceimpl<A, B, C, D, E, F, G, H, I> Zeroize for (A, B, C, D, E, F, G, H, I)
impl<A, B, C, D, E, F, G, H, I> Zeroize for (A, B, C, D, E, F, G, H, I)
Sourceimpl<A, B, C, D, E, F, G, H> Zeroize for (A, B, C, D, E, F, G, H)
impl<A, B, C, D, E, F, G, H> Zeroize for (A, B, C, D, E, F, G, H)
Sourceimpl<A, B, C, D, E, F, G> Zeroize for (A, B, C, D, E, F, G)
impl<A, B, C, D, E, F, G> Zeroize for (A, B, C, D, E, F, G)
Sourceimpl<A, B, C, D, E, F> Zeroize for (A, B, C, D, E, F)
impl<A, B, C, D, E, F> Zeroize for (A, B, C, D, E, F)
Sourceimpl<A, B, C, D, E> Zeroize for (A, B, C, D, E)
impl<A, B, C, D, E> Zeroize for (A, B, C, D, E)
Sourceimpl<A, B, C, D> Zeroize for (A, B, C, D)
impl<A, B, C, D> Zeroize for (A, B, C, D)
Sourceimpl<Z> Zeroize for MaybeUninit<Z>
Impl Zeroize on MaybeUninit types.
impl<Z> Zeroize for MaybeUninit<Z>
Impl Zeroize on MaybeUninit types.
This fills the memory with zeroes.
Note that this ignore invariants that Z might have, because
MaybeUninit removes all invariants.
Sourceimpl<Z> Zeroize for PhantomData<Z>
PhantomData is always zero sized so provide a Zeroize implementation.
impl<Z> Zeroize for PhantomData<Z>
PhantomData is always zero sized so provide a Zeroize implementation.
Sourceimpl<Z> Zeroize for [MaybeUninit<Z>]
Impl Zeroize on slices of MaybeUninit types.
impl<Z> Zeroize for [MaybeUninit<Z>]
Impl Zeroize on slices of MaybeUninit types.
This impl can eventually be optimized using an memset intrinsic,
such as core::intrinsics::volatile_set_memory.
This fills the slice with zeroes.
Note that this ignore invariants that Z might have, because
MaybeUninit removes all invariants.
Sourceimpl<Z> Zeroize for [Z]where
Z: DefaultIsZeroes,
impl<Z> Zeroize for [Z]where
Z: DefaultIsZeroes,
This impl can eventually be optimized using an memset intrinsic,
such as core::intrinsics::volatile_set_memory. For that reason the
blanket impl on slices is bounded by DefaultIsZeroes.
To zeroize a mut slice of Z: Zeroize which does not impl
DefaultIsZeroes, call iter_mut().zeroize().