pub fn consolidate_iter<D: PartialEq, R: Semigroup>(
iter: impl Iterator<Item = (D, R)>,
) -> impl Iterator<Item = (D, R)>Available on crate feature
differential-dataflow only.Expand description
Proactively consolidate adjacent elements in an iterator.
If the input iterator is sorted by D, the outputs will be both sorted and fully consolidated.
If the input is not sorted, the output will probably not be either… but still equivalent from
a differential perspective and slightly smaller.